************************************************************************************************************************
************************************************************************************************************************
* Master do-file
* The (lack of) Distortionary Effects of Proxy-Means Tests: Results from a Nationwide Experiment in Indonesia
* Abhijit Banerjee, Rema Hanna, Benjamin A. Olken, Sudarno Sumarto

* June 2020
************************************************************************************************************************
************************************************************************************************************************

************************************************************
*** 0. preliminaries ***
************************************************************

macro drop _all
set more off
clear

capture ssc install newey2
capture ssc install shp2dta
capture ssc install outreg2

******************************************
* set main directory
******************************************

global rundir " "

******************************************
* set globals
******************************************

global code 			"$rundir/code"
global coding 			"$code/coding"
global analysis 		"$code/analysis"
global pmt				"$code/pmt_exercise"
global fake_tx			"$code/coding/fake_treatments"
global rawdata   		"$rundir/data/rawdata"
global KOR 				"$rawdata/KOR"
global MODULE 			"$rawdata/MODULE"
global codeddata   		"$rundir/data/codeddata"
global interim 			"$codeddata/interim"
global outpath 			"$rundir/output"
global Output 			"$rundir/output"
global logs 			"$rundir/logs"
global balance			"$rundir/data/balance"
global path_ado			"$rundir/ado"

** set toggles for which do files to run: 
local do_coding = 0 // takes roughly 20 minutes to run
local do_analysis = 1 // takes roughly 10 minutes to run
local do_FWER = 0 // takes roughly 3 days days to run
local do_RI = 0 // takes roughly 3 days to run

** start log file:
*cap log close
*log using "$logs/master_log", replace

************************************************************
*** 1. coding
************************************************************

if `do_coding' == 1 { // takes roughly 20 minutes to run on server

*** code 2016 master SUSENAS data set:
do "$coding/Final_Database_2016.do"

*** code 2017 master SUSENAS data set:
do "$coding/Final_Database_2017.do"

** impute missing susenas variables for 2016 and 2017
do "$coding/imputem_susenas.do" 

** prep inds for lasso for 2016 and 2017
do "$coding/lassoprep_inds.do" 

** remove collinear variables for use in Lasso for 2016 and 2017
do "$coding/remove_collinear_vars.do"

** code raw tv data 
do "$coding/tv_coding.do" 

** code raw phone data
do "$coding/phone_coding.do" 

}

***************************************************************
* Do LASSO selection in Matlab and regressions in Stata
***************************************************************

** Run MATLAB lasso selection // select variables by lasso
// "$analysis/MATLAB/lassoregressions_imputem_2016.m" 
// "$analysis/MATLAB/lassoregressions_imputem_2016_alt.m" 
// "$analysis/MATLAB/lassoregressions_imputem_2017.m" 

** Now, copy selected variables from matlabregressions_2016.do, matlabregressions_2016_alt.do, and matlabregressions_2017.do
** into table1.do, table1_alt.do, table1_2017.do, respectively.

************************************************************
*** 3. Tables ***
************************************************************

if `do_analysis' == 1 { // takes roughly 10 minutes to run

** Table 1: Individual Regressions from Survey Data (Lasso controls)
** Appendix Table 4: Individual Regressions from Survey Data (no controls)
** Appendix Table 5: Alternative cell phone outcome variable
do "$analysis/table1.do"
*do "$analysis/table1_alt.do"
do "$analysis/table1_2017.do"

** Table 2: Effect on tv sales
** Appendix Table 6: Effect on tv sales -- data truncated in March 2016
** Appendix Tables 7a/7b: Effect on tv sales -- month and month-year FE
do "$analysis/table2.do"
do "$analysis/appendix_table7.do"

** Table 3: Effect on cellphone sales
** Appendix Table 8: Effect on cellphone sales -- drop Jakarta, robustness check
** Appendix Tables 9-10: Replicated with all years pooled 
do "$analysis/table3.do"
do "$analysis/appendix_table9-10.do"

** Appendix Table 2: Randomization Check
do "$analysis/appendix_table2.do"

** Figure 1: Map of Randomization (we then needed to manually draw the border for the 34th province, saved as "figure1_revised.png")
do "$analysis/figure1.do"

** Figure 2: PMT exercise
do "$pmt/1 clean 2016 susenas.do"
do "$pmt/2 final pmt coding.do"
do "$pmt/3 pmt analysis.do"

** Appendix Table 1: Randomization Matrix (manually created in Word)
** Appendix Table 3: Lasso controls descriptions (manually created in Word)
** Appendix Figure 1: Timeline (manually created in Excel)

}

** Family Wise Error Rate adjusted p-values
** modified version Mike Anderson's do file (for Table 1, Appendix Table 4, and Appendix Table 5)
if `do_FWER' == 1 { // takes roughly 3 days to run
do "$fake_tx/fake randomizations.do"
do "$analysis/FWER Sample Code.do"
do "$analysis/FWER Sample Code alt.do"
}

** Randomization Inference p-values
if `do_RI' == 1 { // takes roughly 3 days to run
do "$analysis/randomization_inference/table1_alt RI.do"
do "$analysis/randomization_inference/table1 RI.do"
do "$analysis/randomization_inference/table1_2017 RI.do"
do "$analysis/randomization_inference/table3 RI.do"
do "$analysis/randomization_inference/appendix_table2 RI.do"
do "$analysis/randomization_inference/appendix_table8 RI.do"
do "$analysis/randomization_inference/appendix_table9-10 RI.do"
}


************************************************************
*** 4. Finish ***
************************************************************

di "DONE WITH MASTER DO FILE!"
***DONE!
cap log close
***DONE!


