
clear all
pause on
set more off
set maxvar 5000

** Randomization for PPLS question project
** Stata version: 13.1 IC
** This version: April 13th 2015
** Author: Gabriel Kreindler (gek@mit.edu, gabriel.kreindler@gmail.com)

*******************************************
* Data coding
*******************************************

//do "`randfolder'150401 coding allyears.do"
** input data: raw susenas data
** output data: randfolder\data_coded\susenas20xx_v1.dta, for xx=10,11,12,14

*******************************************
* Data preparation
*******************************************

use "$balance/coded/susenas2012_v1.dta", clear

* drop Papua
	*drop if province == 91 | province == 94

* labeling provinces
	label var province "Province"
	label define province_codes ///
		11 "Nanggroe Aceh Darussalam" ///
		12 "Sumatera Utara" ///
		13 "Sumatera Barat" ///
		14 "Riau" ///
		15 "Jambi" ///
		16 "Sumatera Selatan" ///
		17 "Bengkulu" ///
		18 "Lampung" ///
		19 "Bangka Belitung" ///
		21 "Kepulauan Riau" ///
		31 "DKI Jakarta" ///
		32 "Jawa Barat" ///
		33 "Jawa Tengah" ///
		34 "DI Yogyakarta" ///
		35 "Jawa Timur" ///
		36 "Banten" ///
		51 "Bali" ///
		52 "Nusa Tenggara Barat" ///
		53 "Nusa Tenggara Timur" ///
		61 "Kalimantan Barat" ///
		62 "Kalimantan Tengah" ///
		63 "Kalimantan Selatan" ///
		64 "Kalimantan Timur" ///
		65 "Kalimantan Utara" ///
		71 "Sulawesi Utara" ///
		72 "Sulawesi Tengah" ///
		73 "Sulawesi Selatan" ///
		74 "Sulawesi Tenggara" ///
		75 "Gorontalo" ///
		76 "Sulawesi Barat" ///
		81 "Maluku" ///
		82 "Maluku Utara" ///
		91 "Papua Barat" ///
		94 "Papua"

	label values province province_codes

* form strata	
	recode province ///
		(11 12 13 14 15 16 17 18 19 21 = 1 "Sumatra") /// 
		(31 32 33 34 35 36 = 2 "Java") /// 
		(81 82 = 3 "Maluku") /// 
		(61 62 63 64 = 4 "Kalimantan") ///   
		(71 72 73 74 75 76 = 5 "Sulawesi") /// 
		(51 52 53 = 6 "Nusa Tenggara") ///
		(91 94 = 7 "Papua") ///
		, gen(strata_orig)
	label var strata_orig "Region (original version)"

* aggregated version of strata <- this is what we use	
	recode province ///
		(11 12 13 14 15 16 17 18 19 21 = 1 "Sumatra") /// 
		(31 32 33 34 35 36 = 2 "Java") /// 
		(51 52 53 81 82 91 94 = 3 "Nusa Tenggara + Maluku + Papua") ///   //<----- NT + Maluku (no papua)
		(61 62 63 64 = 4 "Kalimantan") ///
		(71 72 73 74 75 76 = 5 "Sulawesi") /// 
		, gen(strata)
	label var strata "Region (aggregated version)"
	
* collapse to district level (in order to get #districts per province)
	gen obs = 1 // number of observations 
	collapse (sum) obs weight, by(strata* province district)
	
* collapse to province level
	gen ndistricts = 1 // number of districts
	collapse (sum) obs weight ndistricts, by(strata* province)
	
	label variable obs "Number of observations in SUSENAS 2012"
	label variable weight "Total weight in SUSENAS 2012"
	label variable ndistricts "Number of districts"
	
*******************************************
* Randomization
*******************************************
/*
treatment_`i' P = 0 Question: number of cellphones 
treatment_`i' P = 1 Question: number of swan-neck toilet
treatment_`i' Q = 0 Question: number of TVs
treatment_`i' Q = 1 Question: number of rooms

Randomization algorithm: 

(Step 1) Within each region (Sumatra, Java, Kalimantan, Sulawesi, 
NT+Maluku), we order provinces by the number of districts they have.
We choose randomly one province from NT (the only region with odd number of
province) to move at the end.
** Within NT+Maluku, we first order provinces into Maluku and NT.

This leads to 5 strata plus the randomly chosen province from NT 

(Step 2) Assign treatment_`i' P:
* Move the province from NT last.
* Randomly order strata, keeping unchanged the order within each stratum, 
	and keeping the province from NT last.
* Form pairs of consecutive provinces within each stratum (excluding the last province)
* Randomly order provinces within each pair
* Assign treatment_`i' P in sequence: 1,0,1,0,...
* Randomly flip the treatment_`i' P for everyone

(this is obviously equivalent to randomizing treatment_`i' within each pair; 
however, it is more convenient to sort and then assign P in a period sequence)

(Step 3) Assign treatment_`i' Q:
* Keeping the same order as before:
* Assign treatment_`i' Q alternating sequences (1,0) with (0,1): 1,0,0,1,1,0,0,1,...
* Randomly flip the entire treatment_`i' Q assignment.
*/

set seed 	 4289542 // 150429
set sortseed 4289542 // 150429

local nrand = 1000

forval i = 1/`nrand' {

di as error "on randomization number `i' out of `nrand'..."

*** Sort into pairs
* Sort by aggregated strata, original strata, and then by 
* number of districts (2012). Move Bali and North Kalimantan 
* at the end; these provinces are originally in strata with 
* odd #provinces. Finally, group provinces into pairs.
		
	* pick one province from Nusa Tenggara to be left last
	sort strata_orig, stable
	gen rand_pick = runiform()
	by strata_orig: egen rand_pick_max = max(rand_pick)
	gen move_last = rand_pick == rand_pick_max & strata_orig == 6
	count if move_last==1
	assert r(N)==1
	
	sort strata strata_orig ndistricts, stable
	
	* define pairs - province
	by strata: gen pair_id = ceil(_n/2) if move_last==0
	count if pair_id == 3 & strata_orig==6
	replace pair_id = 2 if pair_id == 3 & strata_orig==6
	
	* check strata unique within pair
	preserve
		keep strata pair_id
		duplicates drop
		assert _N== 18
	restore
	
*** Assign treatment_`i' P
		
	** randomly sort across strata
		gen rand_strata = runiform()
		by strata: replace rand_strata = rand_strata[1]

	* random order within pairs, and assign treatment_`i' P
		gen rand_pair = runiform()
		sort rand_strata pair_id rand_pair

	* move one province from Nusa Tenggara last
		gen     n = _n
		replace n = 35 if move_last == 1
		isid n
		sort n, stable
		
	* assign treatment_`i' P in sequence 10101010
		gen treatP_`i' = mod(_n,2)
		
	* randomly flip everyone's treatment_`i' status.
		gen     rand_flipP = runiform()
		replace rand_flipP = rand_flipP[1]
		replace treatP_`i' = 1 - treatP_`i' if rand_flipP > 0.5
	
*** Assign treatment_`i' Q
	
	* assign treatment_`i' Q in sequence 01100110 etc
		gen     treatQ_`i' = mod(_n,2)
		replace treatQ_`i' = 1 - treatQ_`i' if mod(_n,4)==3 | mod(_n,4)==0
	
	* randomly flip everyone's treatment_`i' status.
		gen     rand_flipQ = runiform()
		replace rand_flipQ = rand_flipQ[1]
		replace treatQ_`i' = 1 - treatQ_`i' if rand_flipQ > 0.5
		
		tab treatP_`i' treatQ_`i'

* define treatment_`i's
	label variable treatP_`i' "treatment_`i' P (0=WC, 1=bike)"
	label variable treatQ_`i' "treatment_`i' Q (0=TV, 1=room)"
	
	label define treatP_`i' 0 "Cell" 1 "WC"
	label values treatP_`i' treatP_`i'
	label define treatQ_`i' 0 "TV" 1 "Room"
	label values treatQ_`i' treatQ_`i'
	
	*gen tr_cell_`i' = treatP_`i'==0
	gen tr_wc_`i'   = treatP_`i'==1
	gen tr_tv_`i'   = treatQ_`i'==0
	*gen tr_room_`i' = treatQ_`i'==1
	
	gen 	treatment_`i' = "P0Q0" if treatP_`i'==0 & treatQ_`i'==0
	replace	treatment_`i' = "P0Q1" if treatP_`i'==0 & treatQ_`i'==1
	replace	treatment_`i' = "P1Q0" if treatP_`i'==1 & treatQ_`i'==0
	replace	treatment_`i' = "P1Q1" if treatP_`i'==1 & treatQ_`i'==1

* drop intermediate vairables	
drop rand_pick rand_pick_max move_last pair_id rand_strata rand_pair n rand_flipP rand_flipQ treatP_`i' treatQ_`i' treatment_`i'

	}

** add in North/Utara Kal, just split off from East/Timor Kal.
gen flag = province == 64
expand 2 if flag == 1
replace province = 65 in 34
drop flag

** correct strata variable
drop strata_orig
rename strata strata_orig

** clean up and save
	*order n rand_strata rand_*, after(tr_room_`i')
	*order treatment_`i', before(treatP_`i')
	
** save final placebo randomizations	
saveold "$fake_tx/fake_tx.dta", replace

	
