*************************************************************
* Lasso Selection for SUSENAS survey experiment
* Suhas Vijaykumar, August 2017
*************************************************************

*************************************************************
** preliminary **
*************************************************************

di "Starting"
di "$S_TIME $S_DATE"

clear
set more off

** loop over both years
forval yr = 2016/2017 {

* Load data
use "$codeddata/180529_final_database_imputem_`yr'susenas.dta", clear

*************************************************************
** Organizing variables **
*************************************************************

// make list of all potential controls for selection
quietly ds *0?_* *1?_*
local survey_covs `r(varlist)'
local lasso_covs `survey_covs' urban

// create dummies for each strata
quietly tab strata_orig, gen(strata_numeric)

*************************************************************
** Prepping for (clustered) Lasso **
*************************************************************

*** There should be no missing variables since we are using the imputed data!
foreach cov in `survey_covs' {
	assert !missing(`cov')
}

// standardize variables -- this is done in matlab code now
di "Standardizing variables."
quietly ds *0?_* *1?_* urban
foreach covariate in `r(varlist)' {
	quietly summ `covariate'
	if r(sd) < 1e-6 { // if std dev tiny, drop
		local to_drop `covariate'
		local lasso_covs : list lasso_covs - to_drop
		quietly drop `covariate'
		di "Dropped `covariate' to enforce no constants"
	}
	else {
		*quietly replace `covariate' = (`covariate' - r(mean)) / r(sd) // this is done in matlab code now
	}
}

// create lasso_covs local
quietly ds *0?_* *1?_* urban
local lasso_covs `r(varlist)'

di "Eliminating pairwise collinearities for year `yr'."
di "$S_TIME"

*************************************************************
** saving final dta file and csv files for matlab **
*************************************************************

// shorten variable names to first 25 characters so lassoCluster doesn't break
foreach v of var * {
	local new = substr("`v'", 1, 25)
	quietly rename `v' `new'
}

// Also encode province and strata as numeric to facilitate import to matlab
quietly egen prov_numeric = group(province)
quietly egen strata_numeric = group(strata_orig)

// save final data set
save "$codeddata/lasso_prepped_inds_imputem_`yr'susenas.dta", replace

// dump data for MATLAB use
qui ds *0?_* *1?_* urban
local vars `r(varlist)'

// save csv files for matlab
outsheet tr_tv using "$analysis/MATLAB/Data_`yr'/tr_tv_inds.csv", comma replace
outsheet tr_cell using "$analysis/MATLAB/Data_`yr'/tr_cell_inds.csv", comma replace
outsheet tr_wc using "$analysis/MATLAB/Data_`yr'/tr_wc_inds.csv", comma replace
outsheet tr_room using "$analysis/MATLAB/Data_`yr'/tr_room_inds.csv", comma replace
outsheet n_cell_hh using "$analysis/MATLAB/Data_`yr'/n_cell_hh_inds.csv", comma replace
outsheet own_flattv using "$analysis/MATLAB/Data_`yr'/own_flattv_inds.csv", comma replace
outsheet own_wcgoose using "$analysis/MATLAB/Data_`yr'/own_wcgoose_inds.csv", comma replace
outsheet total_room using "$analysis/MATLAB/Data_`yr'/total_room_hh_inds.csv", comma replace
outsheet prov_numeric using "$analysis/MATLAB/Data_`yr'/province_numeric_inds.csv", comma replace
outsheet strata_numeric using "$analysis/MATLAB/Data_`yr'/strata_numeric_inds.csv", comma replace

// alternative cell phone variable in 2016
if `yr' == 2016 outsheet n_ppl_phones using "$analysis/MATLAB/Data_`yr'/n_ppl_phones_inds.csv", comma replace

} 

*DONE!!!




