**************************************
**************************************
** PMT exercise for PPLS paper
**************************************
**************************************

**************************************
** 0. preliminaries
**************************************

*** SET SEED
set seed 190130

clear
set more off

**************************************
** 1. main analysis
**************************************

foreach outcome in h_own_flattv h_n_cell_hh h_total_room h_own_wcgoose {

** load in SUSENAS 2016 data
use "$codeddata/SUSENAS2016_all_variables_JEP_FINAL.dta", clear 

** should be household-level
isid hhid

** only keep control group
if "`outcome'" == "h_own_flattv" keep if tr_tv == 0
if "`outcome'" == "h_n_cell_hh" keep if tr_cell == 0
if "`outcome'" == "h_total_room" keep if tr_room == 0
if "`outcome'" == "h_own_wcgoose" keep if tr_wc == 0

***SPECIFY TRAINING/TEST DATA***
generate random = runiform()
sort random 
generate training = ceil(2 * _n/_N) - 1
drop random 

** label tv variable
label var h_own_flattv "Own TV"

** generate logPCE
gen lnpercapitaconsumption = ln(exp_cap)

local ommitted_note "Ommitted categories: HH head age 51+; Household size more than 4; 0 dependent children; HH head has no education; services occupation; family workers employment status; other roof; other walls; other floor; other house; other drinking water source; not buying drinking water; no access to toilet; other disposal method; no electricity."

** regress ln consumption on asset dummies for TRAINING data only 
** note: we use the same variables here that were used in
** "Universal Basic Incomes vs. Targeted Transfers: Anti-Poverty Programs in Developing Countries" (JPE, 2018)
reg lnpercapitaconsumption `outcome' d_* if training == 1, vce(robust)
sum lnpercapitaconsumption if e(sample) == 1
*outreg2 using "$outpath/pmt_jep_exercise_`outcome'.doc", replace label addnote("`ommitted_note'") nocons adds("Control mean", `r(mean)') ctitle("With tv control") title("PPLS Paper, PMT Coefficients using JEP Variables")
display _b[`outcome']
local omega = _b[`outcome']

** predict ln consumption in the TEST set 
predict lncaphat if training == 0

** drop those in training set
keep if training == 0

** find percentile of what log pce corresponds with 1.5 * poverty line
order hhid province h_urban lnpercapitaconsumption ln_poverty_line_1_5
sort province h_urban lnpercapitaconsumption 
bysort province h_urban: gen num = _n
bysort province h_urban: gen den = _N
gen cdf = num / den 
gen flag = lnpercapitaconsumption > ln_poverty_line_1_5 
replace cdf = 1 if flag == 0
bysort province h_urban: egen cdf_min = min(cdf)
drop num den flag

** find predicted logPCE that corresponds with that percentile
sort province h_urban lncaphat 
bysort province h_urban: gen num = _n
bysort province h_urban: gen den = _N
gen cdf_predict = num / den 
gen flag = cdf_predict == cdf_min
gen helper = lncaphat if flag == 1
bysort province h_urban: egen poverty_threshold = max(helper)
drop num den helper

** generate variable if receiving benefits
gen receive_benefits = cdf_predict <= cdf_min
tab receive_benefits, m
bysort receive_benefits: sum h_own_flattv

** order and sort variables
order province h_urban lncaphat lnpercapitaconsumption receive_benefits poverty_threshold flag cdf*
sort province h_urban lncaphat 

** alpha is poverty threshold
rename poverty_threshold alpha

** signma is standard deviation of noise (measurement error)
** note: this is taken from Figure 1b of self-targeting paper (https://economics.mit.edu/files/9979, Alatas et al (2016))
preserve
	use "$pmt/matched_baseline.dta", clear
	egen kab_urban = group(urban kabgroup)
	probit getbenefit PMTSCORE i.kab_urban if showup==1 
	predict mu_pmt
	di _b[PMTSCORE]
	local sigma = 1 / abs(_b[PMTSCORE])
	di `sigma' // --> note: this is the prediction error
restore

** generate probalities
gen sigma = `sigma'
gen omega = `omega'
gen inside1 = (alpha - lncaphat) / sigma
gen inside2 = (alpha - lncaphat + omega) / sigma
gen prob1 = normal(inside1)
gen prob2 = normal(inside2)
drop sigma omega inside*

** generate diffference in probabilities
gen diff = prob2 - prob1
label var diff "Percentage point increase"

order prob* diff province h_urban lncaphat lnpercapitaconsumption receive_benefits alpha flag cdf*

**************************************
** 2. final output
**************************************

** only keep households that own a television
if "`outcome'" == "h_own_flattv" keep if h_own_flattv == 1
if "`outcome'" == "h_n_cell_hh" keep if h_n_cell_hh > 0 & !missing(h_n_cell_hh)
if "`outcome'" == "h_total_room" keep if h_total_room > 0 & !missing(h_total_room)
if "`outcome'" == "h_own_wcgoose" keep if h_own_wcgoose == 1

if "`outcome'" == "h_own_flattv" local title "Own TV"
if "`outcome'" == "h_n_cell_hh" local title "Number Sim Cards"
if "`outcome'" == "h_total_room" local title "Number Rooms"
if "`outcome'" == "h_own_wcgoose" local title "Own WC"

** create graph
scatter diff lncaphat, xlabel(12 (1) 16) ylabel(0 (.03) .12, gmin gmax) msize(0.2) graphregion(color(white)) xtitle("Predicted log consumption (PMT Score)") title("`title'") saving(`outcome', replace)
*graph export "$outpath/figure2_pmt_figure_`outcome'.png", replace

}

** combine graphs
gr combine h_own_flattv.gph h_n_cell_hh.gph h_total_room.gph h_own_wcgoose.gph, graphregion(color(white))
graph export "$outpath/figure2_pmt_figure_ALL4.png", replace



*DONE!


